@@ -42,13 +42,16 @@ to easily interact with OpenAI APIs for tasks like generating responses or embed
 import inspect
 import json
 import logging
-from typing import Awaitable, Callable, List, Type, TypeVar
+from collections.abc import Awaitable, Callable
+from typing import TypeVar
 
 import numpy as np
 import pandas as pd
 import tiktoken
 from openai import AsyncOpenAI, OpenAI
 
+from openaivec._schema import InferredSchema, SchemaInferenceInput, SchemaInferer
+
 __all__ = [
     "embeddings_model",
     "responses_model",
@@ -177,7 +180,7 @@ class OpenAIVecSeriesAccessor:
         self,
         instructions: str,
         cache: BatchingMapProxy[str, ResponseFormat],
-        response_format: Type[ResponseFormat] = str,
+        response_format: type[ResponseFormat] = str,
         temperature: float | None = 0.0,
         top_p: float = 1.0,
         **api_kwargs,
@@ -191,7 +194,7 @@ class OpenAIVecSeriesAccessor:
             instructions (str): System prompt prepended to every user message.
             cache (BatchingMapProxy[str, ResponseFormat]): Explicit cache instance for
                 batching and deduplication control.
-            response_format (Type[ResponseFormat], optional): Pydantic model or built-in
+            response_format (type[ResponseFormat], optional): Pydantic model or built-in
                 type the assistant should return. Defaults to ``str``.
             temperature (float | None, optional): Sampling temperature. Defaults to ``0.0``.
             top_p (float, optional): Nucleus sampling parameter. Defaults to ``1.0``.
@@ -219,7 +222,7 @@ class OpenAIVecSeriesAccessor:
     def responses(
         self,
         instructions: str,
-        response_format: Type[ResponseFormat] = str,
+        response_format: type[ResponseFormat] = str,
         batch_size: int | None = None,
         temperature: float | None = 0.0,
         top_p: float = 1.0,
@@ -245,7 +248,7 @@ class OpenAIVecSeriesAccessor:
 
         Args:
             instructions (str): System prompt prepended to every user message.
-            response_format (Type[ResponseFormat], optional): Pydantic model or built‑in
+            response_format (type[ResponseFormat], optional): Pydantic model or built‑in
                 type the assistant should return. Defaults to ``str``.
             batch_size (int | None, optional): Number of prompts grouped into a single
                 request. Defaults to ``None`` (automatic batch size optimization
@@ -434,6 +437,61 @@ class OpenAIVecSeriesAccessor:
             **api_kwargs,
         )
 
+    def infer_schema(self, purpose: str, max_examples: int = 100) -> InferredSchema:
+        """Infer a structured data schema from Series content using AI.
+
+        This method analyzes a sample of the Series values to automatically infer
+        a structured schema that can be used for consistent data extraction.
+        The inferred schema includes field names, types, descriptions, and
+        potential enum values based on patterns found in the data.
+
+        Args:
+            purpose (str): Plain language description of how the extracted
+                structured data will be used (e.g., "Extract customer sentiment
+                signals for analytics", "Parse product features for search").
+                This guides field relevance and helps exclude irrelevant information.
+            max_examples (int): Maximum number of examples to analyze from the
+                Series. The method will sample randomly from the Series up to this
+                limit. Defaults to 100.
+
+        Returns:
+            InferredSchema: An object containing:
+                - purpose: Normalized statement of the extraction objective
+                - fields: List of field specifications with names, types, and descriptions
+                - inference_prompt: Reusable prompt for future extractions
+                - model: Dynamically generated Pydantic model for parsing
+                - task: PreparedTask for batch extraction operations
+
+        Example:
+            ```python
+            reviews = pd.Series([
+                "Great product! Fast shipping and excellent quality.",
+                "Terrible experience. Item broke after 2 days.",
+                "Average product. Price is fair but nothing special."
+            ])
+
+            # Infer schema for sentiment analysis
+            schema = reviews.ai.infer_schema(
+                purpose="Extract sentiment and product quality indicators"
+            )
+
+            # Use the inferred schema for batch extraction
+            extracted = reviews.ai.task(schema.task)
+            ```
+
+        Note:
+            The schema inference uses AI to analyze patterns in the data and may
+            require multiple attempts to produce a valid schema. Fields are limited
+            to primitive types (string, integer, float, boolean) with optional
+            enum values for categorical fields.
+        """
+        inferer = CONTAINER.resolve(SchemaInferer)
+
+        input: SchemaInferenceInput = SchemaInferenceInput(
+            examples=self._obj.sample(n=min(max_examples, len(self._obj))).tolist(), purpose=purpose
+        )
+        return inferer.infer_schema(input)
+
     def count_tokens(self) -> pd.Series:
         """Count `tiktoken` tokens per row.
 
@@ -480,6 +538,90 @@ class OpenAIVecSeriesAccessor:
             extracted.columns = [f"{self._obj.name}_{col}" for col in extracted.columns]
         return extracted
 
+    def auto_extract(
+        self,
+        purpose: str,
+        max_examples: int = 100,
+        batch_size: int | None = None,
+        show_progress: bool = False,
+        **api_kwargs,
+    ) -> pd.DataFrame:
+        """Automatically infer schema and extract structured data in one step.
+
+        This convenience method combines schema inference and data extraction into
+        a single operation. It first analyzes a sample of the Series to infer an
+        appropriate schema based on the stated purpose, then immediately applies
+        that schema to extract structured data from all values in the Series.
+
+        Args:
+            purpose (str): Plain language description of what information to extract
+                and how it will be used (e.g., "Extract product features for search",
+                "Parse customer feedback for sentiment analysis"). This guides both
+                schema inference and field selection.
+            max_examples (int): Maximum number of examples to use for schema inference.
+                A larger sample may produce more accurate schemas but increases
+                inference time. Defaults to 100.
+            batch_size (int | None): Number of requests to process in parallel during
+                extraction. Defaults to None (automatic optimization). Set to a specific
+                value to control API usage and performance.
+            show_progress (bool): Whether to display a progress bar during extraction.
+                Useful for large datasets. Defaults to False.
+            **api_kwargs: Additional OpenAI API parameters (e.g., `temperature`, `top_p`,
+                `frequency_penalty`, `presence_penalty`, `seed`) forwarded to the task execution.
+
+        Returns:
+            pd.DataFrame: A DataFrame with extracted structured data. Each inferred
+                field becomes a column, with the same index as the original Series.
+                Column names and types are determined by the inferred schema.
+
+        Example:
+            ```python
+            # Extract structured data from product reviews
+            reviews = pd.Series([
+                "Great laptop! 16GB RAM, fast SSD, battery lasts 10 hours",
+                "Decent phone. 128GB storage, camera is okay, screen is bright",
+                "Gaming desktop with RTX 4090, 32GB RAM, runs everything smoothly"
+            ])
+
+            # One-step extraction
+            extracted = reviews.ai.auto_extract(
+                purpose="Extract product specifications and performance metrics",
+                show_progress=True
+            )
+            # Result: DataFrame with columns like 'ram', 'storage', 'battery_life', etc.
+
+            # Extract sentiment and issues from support tickets
+            tickets = pd.Series([
+                "Account locked, can't reset password, very frustrated",
+                "Billing error, charged twice for subscription",
+                "Great support! Issue resolved quickly"
+            ])
+
+            features = tickets.ai.auto_extract(
+                purpose="Extract issue type and customer sentiment for support analytics"
+            )
+            ```
+
+        Note:
+            This method is ideal for exploratory data analysis when you don't have
+            a predefined schema. For production use cases with stable schemas,
+            consider using `infer_schema()` once and reusing the schema with `task()`.
+            The inferred schema is not returned, so if you need to inspect or save it,
+            use `infer_schema()` and `task()` separately.
+        """
+        schema = self._obj.ai.infer_schema(purpose=purpose, max_examples=max_examples)
+
+        return pd.DataFrame(
+            {
+                "inferred": self._obj.ai.task(
+                    task=schema.task,
+                    batch_size=batch_size,
+                    show_progress=show_progress,
+                    **api_kwargs,
+                ),
+            }
+        ).ai.extract("inferred")
+
 
 @pd.api.extensions.register_dataframe_accessor("ai")
 class OpenAIVecDataFrameAccessor:
@@ -492,7 +634,7 @@ class OpenAIVecDataFrameAccessor:
         self,
         instructions: str,
         cache: BatchingMapProxy[str, ResponseFormat],
-        response_format: Type[ResponseFormat] = str,
+        response_format: type[ResponseFormat] = str,
         temperature: float | None = 0.0,
         top_p: float = 1.0,
         **api_kwargs,
@@ -526,7 +668,7 @@ class OpenAIVecDataFrameAccessor:
             cache (BatchingMapProxy[str, ResponseFormat]): Pre-configured cache
                 instance for managing API call batching and deduplication.
                 Set cache.batch_size=None to enable automatic batch size optimization.
-            response_format (Type[ResponseFormat], optional): Desired Python type of the
+            response_format (type[ResponseFormat], optional): Desired Python type of the
                 responses. Defaults to ``str``.
             temperature (float | None, optional): Sampling temperature. Defaults to ``0.0``.
             top_p (float, optional): Nucleus sampling parameter. Defaults to ``1.0``.
@@ -546,7 +688,7 @@ class OpenAIVecDataFrameAccessor:
     def responses(
         self,
         instructions: str,
-        response_format: Type[ResponseFormat] = str,
+        response_format: type[ResponseFormat] = str,
         batch_size: int | None = None,
         temperature: float | None = 0.0,
         top_p: float = 1.0,
@@ -576,7 +718,7 @@ class OpenAIVecDataFrameAccessor:
 
         Args:
             instructions (str): System prompt for the assistant.
-            response_format (Type[ResponseFormat], optional): Desired Python type of the
+            response_format (type[ResponseFormat], optional): Desired Python type of the
                 responses. Defaults to ``str``.
             batch_size (int | None, optional): Number of requests sent in one batch.
                 Defaults to ``None`` (automatic batch size optimization
@@ -680,6 +822,62 @@ class OpenAIVecDataFrameAccessor:
             **api_kwargs,
         )
 
+    def infer_schema(self, purpose: str, max_examples: int = 100) -> InferredSchema:
+        """Infer a structured data schema from DataFrame rows using AI.
+
+        This method analyzes a sample of DataFrame rows to automatically infer
+        a structured schema that can be used for consistent data extraction.
+        Each row is converted to JSON format and analyzed to identify patterns,
+        field types, and potential categorical values.
+
+        Args:
+            purpose (str): Plain language description of how the extracted
+                structured data will be used (e.g., "Extract operational metrics
+                for dashboard", "Parse customer attributes for segmentation").
+                This guides field relevance and helps exclude irrelevant information.
+            max_examples (int): Maximum number of rows to analyze from the
+                DataFrame. The method will sample randomly up to this limit.
+                Defaults to 100.
+
+        Returns:
+            InferredSchema: An object containing:
+                - purpose: Normalized statement of the extraction objective
+                - fields: List of field specifications with names, types, and descriptions
+                - inference_prompt: Reusable prompt for future extractions
+                - model: Dynamically generated Pydantic model for parsing
+                - task: PreparedTask for batch extraction operations
+
+        Example:
+            ```python
+            df = pd.DataFrame({
+                'text': [
+                    "Order #123: Shipped to NYC, arriving Tuesday",
+                    "Order #456: Delayed due to weather, new ETA Friday",
+                    "Order #789: Delivered to customer in LA"
+                ],
+                'timestamp': ['2024-01-01', '2024-01-02', '2024-01-03']
+            })
+
+            # Infer schema for logistics tracking
+            schema = df.ai.infer_schema(
+                purpose="Extract shipping status and location data for logistics tracking"
+            )
+
+            # Apply the schema to extract structured data
+            extracted_df = df.ai.task(schema.task)
+            ```
+
+        Note:
+            The DataFrame rows are internally converted to JSON format before
+            analysis. The inferred schema is flat (no nested structures) and
+            uses only primitive types to ensure compatibility with pandas and
+            Spark operations.
+        """
+        return _df_rows_to_json_series(self._obj).ai.infer_schema(
+            purpose=purpose,
+            max_examples=max_examples,
+        )
+
     def extract(self, column: str) -> pd.DataFrame:
         """Flatten one column of Pydantic models/dicts into top‑level columns.
 
@@ -772,7 +970,7 @@ class OpenAIVecDataFrameAccessor:
         if missing_rows.empty:
             return self._obj
 
-        filled_values: List[FillNaResponse] = missing_rows.ai.task(
+        filled_values: list[FillNaResponse] = missing_rows.ai.task(
             task=task, batch_size=batch_size, show_progress=show_progress, **api_kwargs
         )
 
@@ -790,6 +988,100 @@ class OpenAIVecDataFrameAccessor:
 
         return df
 
+    def auto_extract(
+        self,
+        purpose: str,
+        max_examples: int = 100,
+        batch_size: int | None = None,
+        show_progress: bool = False,
+        **api_kwargs,
+    ) -> pd.DataFrame:
+        """Automatically infer schema and add extracted fields to the DataFrame.
+
+        This convenience method combines schema inference and data extraction to
+        automatically add new columns to the existing DataFrame. It analyzes a
+        sample of the DataFrame rows to infer an appropriate schema based on the
+        stated purpose, then extracts structured data and joins it with the
+        original DataFrame.
+
+        Args:
+            purpose (str): Plain language description of what information to extract
+                and how it will be used (e.g., "Extract customer sentiment metrics",
+                "Parse product attributes for analytics"). This guides both schema
+                inference and field selection.
+            max_examples (int): Maximum number of rows to use for schema inference.
+                A larger sample may produce more accurate schemas but increases
+                inference time. Defaults to 100.
+            batch_size (int | None): Number of requests to process in parallel during
+                extraction. Defaults to None (automatic optimization). Set to a specific
+                value to control API usage and performance.
+            show_progress (bool): Whether to display a progress bar during extraction.
+                Useful for large datasets. Defaults to False.
+            **api_kwargs: Additional OpenAI API parameters (e.g., `temperature`, `top_p`,
+                `frequency_penalty`, `presence_penalty`, `seed`) forwarded to the task execution.
+
+        Returns:
+            pd.DataFrame: The original DataFrame with new columns added from the
+                inferred structured data. Each inferred field becomes a new column.
+                The original columns and index are preserved.
+
+        Example:
+            ```python
+            # Add sentiment and issue type to support tickets
+            df = pd.DataFrame({
+                'ticket_id': [1, 2, 3],
+                'description': [
+                    "Can't login, password reset not working",
+                    "Billing error, charged twice last month",
+                    "Great service, issue resolved quickly!"
+                ],
+                'date': ['2024-01-01', '2024-01-02', '2024-01-03']
+            })
+
+            # Add inferred fields to existing DataFrame
+            enriched_df = df.ai.auto_extract(
+                purpose="Extract issue type and sentiment for support dashboard",
+                show_progress=True
+            )
+            # Result: Original df with new columns like 'issue_type', 'sentiment', etc.
+
+            # Add product specifications to inventory data
+            inventory = pd.DataFrame({
+                'sku': ['A001', 'B002', 'C003'],
+                'description': [
+                    "Laptop 16GB RAM, 512GB SSD, Intel i7",
+                    "Phone 128GB, 5G, dual camera",
+                    "Tablet 10-inch, WiFi only, 64GB"
+                ]
+            })
+
+            enriched_inventory = inventory.ai.auto_extract(
+                purpose="Extract technical specifications for inventory system"
+            )
+            ```
+
+        Note:
+            This method is ideal for enriching existing DataFrames with additional
+            structured fields extracted from text columns. The schema is inferred
+            from the entire DataFrame content (converted to JSON format). For
+            production use cases with stable schemas, consider using `infer_schema()`
+            once and reusing the schema with `task()`.
+        """
+        # Infer schema from DataFrame rows
+        schema = self._obj.ai.infer_schema(purpose=purpose, max_examples=max_examples)
+
+        # Extract structured data using the inferred schema
+        inferred_series = self._obj.ai.task(
+            task=schema.task,
+            batch_size=batch_size,
+            show_progress=show_progress,
+            **api_kwargs,
+        )
+
+        return self._obj.assign(
+            inferred=inferred_series,
+        ).ai.extract("inferred")
+
     def similarity(self, col1: str, col2: str) -> pd.Series:
         """Compute cosine similarity between two columns containing embedding vectors.
 
@@ -832,7 +1124,7 @@ class AsyncOpenAIVecSeriesAccessor:
         self,
         instructions: str,
         cache: AsyncBatchingMapProxy[str, ResponseFormat],
-        response_format: Type[ResponseFormat] = str,
+        response_format: type[ResponseFormat] = str,
         temperature: float | None = 0.0,
         top_p: float = 1.0,
         **api_kwargs,
@@ -859,7 +1151,7 @@ class AsyncOpenAIVecSeriesAccessor:
             cache (AsyncBatchingMapProxy[str, ResponseFormat]): Pre-configured cache
                 instance for managing API call batching and deduplication.
                 Set cache.batch_size=None to enable automatic batch size optimization.
-            response_format (Type[ResponseFormat], optional): Pydantic model or built‑in
+            response_format (type[ResponseFormat], optional): Pydantic model or built‑in
                 type the assistant should return. Defaults to ``str``.
             temperature (float | None, optional): Sampling temperature. ``None`` omits the
                 parameter (recommended for reasoning models). Defaults to ``0.0``.
@@ -890,7 +1182,7 @@ class AsyncOpenAIVecSeriesAccessor:
     async def responses(
         self,
         instructions: str,
-        response_format: Type[ResponseFormat] = str,
+        response_format: type[ResponseFormat] = str,
         batch_size: int | None = None,
         temperature: float | None = 0.0,
         top_p: float = 1.0,
@@ -918,7 +1210,7 @@ class AsyncOpenAIVecSeriesAccessor:
 
         Args:
             instructions (str): System prompt prepended to every user message.
-            response_format (Type[ResponseFormat], optional): Pydantic model or built‑in
+            response_format (type[ResponseFormat], optional): Pydantic model or built‑in
                 type the assistant should return. Defaults to ``str``.
             batch_size (int | None, optional): Number of prompts grouped into a single
                 request. Defaults to ``None`` (automatic batch size optimization
@@ -1165,6 +1457,96 @@ class AsyncOpenAIVecSeriesAccessor:
             **api_kwargs,
         )
 
+    async def auto_extract(
+        self,
+        purpose: str,
+        max_examples: int = 100,
+        batch_size: int | None = None,
+        max_concurrency: int = 8,
+        show_progress: bool = False,
+        **api_kwargs,
+    ) -> pd.DataFrame:
+        """Automatically infer schema and extract structured data in one step (asynchronously).
+
+        This convenience method combines schema inference and data extraction into
+        a single operation. It first analyzes a sample of the Series to infer an
+        appropriate schema based on the stated purpose, then immediately applies
+        that schema to extract structured data from all values in the Series.
+
+        Args:
+            purpose (str): Plain language description of what information to extract
+                and how it will be used (e.g., "Extract product features for search",
+                "Parse customer feedback for sentiment analysis"). This guides both
+                schema inference and field selection.
+            max_examples (int): Maximum number of examples to use for schema inference.
+                A larger sample may produce more accurate schemas but increases
+                inference time. Defaults to 100.
+            batch_size (int | None): Number of requests to process in parallel during
+                extraction. Defaults to None (automatic optimization). Set to a specific
+                value to control API usage and performance.
+            max_concurrency (int): Maximum number of concurrent requests during
+                extraction. Defaults to 8.
+            show_progress (bool): Whether to display a progress bar during extraction.
+                Useful for large datasets. Defaults to False.
+            **api_kwargs: Additional OpenAI API parameters (e.g., `temperature`, `top_p`,
+                `frequency_penalty`, `presence_penalty`, `seed`) forwarded to the task execution.
+
+        Returns:
+            pd.DataFrame: A DataFrame with extracted structured data. Each inferred
+                field becomes a column, with the same index as the original Series.
+                Column names and types are determined by the inferred schema.
+
+        Example:
+            ```python
+            # Extract structured data from product reviews
+            reviews = pd.Series([
+                "Great laptop! 16GB RAM, fast SSD, battery lasts 10 hours",
+                "Decent phone. 128GB storage, camera is okay, screen is bright",
+                "Gaming desktop with RTX 4090, 32GB RAM, runs everything smoothly"
+            ])
+
+            # One-step extraction (must be awaited)
+            extracted = await reviews.aio.auto_extract(
+                purpose="Extract product specifications and performance metrics",
+                max_concurrency=4,
+                show_progress=True
+            )
+            # Result: DataFrame with columns like 'ram', 'storage', 'battery_life', etc.
+
+            # Extract sentiment and issues from support tickets
+            tickets = pd.Series([
+                "Account locked, can't reset password, very frustrated",
+                "Billing error, charged twice for subscription",
+                "Great support! Issue resolved quickly"
+            ])
+
+            features = await tickets.aio.auto_extract(
+                purpose="Extract issue type and customer sentiment for support analytics",
+                batch_size=32
+            )
+            ```
+
+        Note:
+            This is an asynchronous method and must be awaited. This method is ideal
+            for exploratory data analysis when you don't have a predefined schema.
+            For production use cases with stable schemas, consider using the synchronous
+            `infer_schema()` once and reusing the schema with `task()`. The inferred
+            schema is not returned, so if you need to inspect or save it, use
+            `infer_schema()` and `task()` separately.
+        """
+        # Use synchronous infer_schema since it's not async
+        schema = self._obj.ai.infer_schema(purpose=purpose, max_examples=max_examples)
+
+        inferred_series = await self._obj.aio.task(
+            task=schema.task,
+            batch_size=batch_size,
+            max_concurrency=max_concurrency,
+            show_progress=show_progress,
+            **api_kwargs,
+        )
+
+        return pd.DataFrame({"inferred": inferred_series}).ai.extract("inferred")
+
 
 @pd.api.extensions.register_dataframe_accessor("aio")
 class AsyncOpenAIVecDataFrameAccessor:
@@ -1177,7 +1559,7 @@ class AsyncOpenAIVecDataFrameAccessor:
         self,
         instructions: str,
         cache: AsyncBatchingMapProxy[str, ResponseFormat],
-        response_format: Type[ResponseFormat] = str,
+        response_format: type[ResponseFormat] = str,
         temperature: float | None = 0.0,
         top_p: float = 1.0,
         **api_kwargs,
@@ -1213,7 +1595,7 @@ class AsyncOpenAIVecDataFrameAccessor:
             cache (AsyncBatchingMapProxy[str, ResponseFormat]): Pre-configured cache
                 instance for managing API call batching and deduplication.
                 Set cache.batch_size=None to enable automatic batch size optimization.
-            response_format (Type[ResponseFormat], optional): Desired Python type of the
+            response_format (type[ResponseFormat], optional): Desired Python type of the
                 responses. Defaults to ``str``.
             temperature (float | None, optional): Sampling temperature. Defaults to ``0.0``.
             top_p (float, optional): Nucleus sampling parameter. Defaults to ``1.0``.
@@ -1237,7 +1619,7 @@ class AsyncOpenAIVecDataFrameAccessor:
     async def responses(
         self,
         instructions: str,
-        response_format: Type[ResponseFormat] = str,
+        response_format: type[ResponseFormat] = str,
         batch_size: int | None = None,
         temperature: float | None = 0.0,
         top_p: float = 1.0,
@@ -1269,7 +1651,7 @@ class AsyncOpenAIVecDataFrameAccessor:
 
         Args:
             instructions (str): System prompt for the assistant.
-            response_format (Type[ResponseFormat], optional): Desired Python type of the
+            response_format (type[ResponseFormat], optional): Desired Python type of the
                 responses. Defaults to ``str``.
             batch_size (int | None, optional): Number of requests sent in one batch.
                 Defaults to ``None`` (automatic batch size optimization
@@ -1555,7 +1937,7 @@ class AsyncOpenAIVecDataFrameAccessor:
         if missing_rows.empty:
             return self._obj
 
-        filled_values: List[FillNaResponse] = await missing_rows.aio.task(
+        filled_values: list[FillNaResponse] = await missing_rows.aio.task(
             task=task, batch_size=batch_size, max_concurrency=max_concurrency, show_progress=show_progress, **api_kwargs
         )
 
@@ -1572,3 +1954,103 @@ class AsyncOpenAIVecDataFrameAccessor:
                 df.at[actual_index, target_column_name] = result.output
 
         return df
+
+    async def auto_extract(
+        self,
+        purpose: str,
+        max_examples: int = 100,
+        batch_size: int | None = None,
+        max_concurrency: int = 8,
+        show_progress: bool = False,
+        **api_kwargs,
+    ) -> pd.DataFrame:
+        """Automatically infer schema and add extracted fields to the DataFrame (asynchronously).
+
+        This convenience method combines schema inference and data extraction to
+        automatically add new columns to the existing DataFrame. It analyzes a
+        sample of the DataFrame rows to infer an appropriate schema based on the
+        stated purpose, then extracts structured data and joins it with the
+        original DataFrame.
+
+        Args:
+            purpose (str): Plain language description of what information to extract
+                and how it will be used (e.g., "Extract customer sentiment metrics",
+                "Parse product attributes for analytics"). This guides both schema
+                inference and field selection.
+            max_examples (int): Maximum number of rows to use for schema inference.
+                A larger sample may produce more accurate schemas but increases
+                inference time. Defaults to 100.
+            batch_size (int | None): Number of requests to process in parallel during
+                extraction. Defaults to None (automatic optimization). Set to a specific
+                value to control API usage and performance.
+            max_concurrency (int): Maximum number of concurrent requests during
+                extraction. Defaults to 8.
+            show_progress (bool): Whether to display a progress bar during extraction.
+                Useful for large datasets. Defaults to False.
+            **api_kwargs: Additional OpenAI API parameters (e.g., `temperature`, `top_p`,
+                `frequency_penalty`, `presence_penalty`, `seed`) forwarded to the task execution.
+
+        Returns:
+            pd.DataFrame: The original DataFrame with new columns added from the
+                inferred structured data. Each inferred field becomes a new column.
+                The original columns and index are preserved.
+
+        Example:
+            ```python
+            # Add sentiment and issue type to support tickets
+            df = pd.DataFrame({
+                'ticket_id': [1, 2, 3],
+                'description': [
+                    "Can't login, password reset not working",
+                    "Billing error, charged twice last month",
+                    "Great service, issue resolved quickly!"
+                ],
+                'date': ['2024-01-01', '2024-01-02', '2024-01-03']
+            })
+
+            # Add inferred fields to existing DataFrame (must be awaited)
+            enriched_df = await df.aio.auto_extract(
+                purpose="Extract issue type and sentiment for support dashboard",
+                max_concurrency=4,
+                show_progress=True
+            )
+            # Result: Original df with new columns like 'issue_type', 'sentiment', etc.
+
+            # Add product specifications to inventory data
+            inventory = pd.DataFrame({
+                'sku': ['A001', 'B002', 'C003'],
+                'description': [
+                    "Laptop 16GB RAM, 512GB SSD, Intel i7",
+                    "Phone 128GB, 5G, dual camera",
+                    "Tablet 10-inch, WiFi only, 64GB"
+                ]
+            })
+
+            enriched_inventory = await inventory.aio.auto_extract(
+                purpose="Extract technical specifications for inventory system",
+                batch_size=32
+            )
+            ```
+
+        Note:
+            This is an asynchronous method and must be awaited. This method is ideal
+            for enriching existing DataFrames with additional structured fields
+            extracted from text columns. The schema is inferred synchronously from
+            the DataFrame content. For production use cases with stable schemas,
+            consider using `infer_schema()` once and reusing the schema with `task()`.
+        """
+        # Infer schema from DataFrame rows (synchronous)
+        schema = self._obj.ai.infer_schema(purpose=purpose, max_examples=max_examples)
+
+        # Extract structured data using the inferred schema (asynchronous)
+        inferred_series = await self._obj.aio.task(
+            task=schema.task,
+            batch_size=batch_size,
+            max_concurrency=max_concurrency,
+            show_progress=show_progress,
+            **api_kwargs,
+        )
+
+        return self._obj.assign(
+            inferred=inferred_series,
+        ).ai.extract("inferred")
